==> holiday_predictor-0.11.0.tar.gz: holiday_predictor-0.11.0/README.md <==
# Holiday Predictor / 假期预测器

<div style="display: flex; align-items: center; justify-content: center; margin: 10px">
      <img
        align=center
        src="https://img.shields.io/github/stars/azaz-az/holiday-predictor?style=for-the-badge&logoColor=%231677ff&labelColor=rgb(89, 89, 89)&color=rgb(3, 126, 187)"
        style="margin: 0 5px"
      />
    <img
        align=center
        src="https://img.shields.io/github/watchers/azaz-az/holiday-predictor?style=for-the-badge&logoColor=%231677ff&labelColor=rgb(89, 89, 89)&color=rgb(3, 126, 187)"
        style="margin: 0 5px"
      />
    <img
        align=center
        src="https://img.shields.io/github/forks/azaz-az/holiday-predictor?style=for-the-badge&logoColor=%231677ff&labelColor=rgb(89, 89, 89)&color=rgb(3, 126, 187)"
        style="margin: 0 5px"
      />
</div>

***

简体中文 (中国大陆) / [English (US)](./README_en_us.md)

***

> [!WARNING]
> 此小工具仅用作假期安排的预测，不一定准确，仅供参考，并不完全代表假期安排。

这个小工具可以预测后续国庆、元旦、清明、端午和中秋的放假安排, 例如什么时候放假、什么时候调休。

本仓库在 GitHub 上开源，同时在 PyPI 上发布。

[![Click To GitHub Repo](https://img.shields.io/badge/click_to-github_repo-%2300fffd?style=for-the-badge)](https://github.com/azaz-az/holiday-predictor)
[![Click To PyPI](https://img.shields.io/badge/click_to-pypi-%23fdda50?style=for-the-badge)](https://pypi.org/project/holiday_predictor/)

贡献者名单：

[![Click To Contributors List](https://img.shields.io/badge/click_to-contributors_list-%2362ff7b?style=for-the-badge)](https://github.com/azaz-az/holiday-predictor/graphs/contributors)

> [!TIP]
> 这个小工具还可以作为模块导入.
> 
> 模块安装方式：
> 
> ```
> pip install holiday_predictor
> ```

本项目使用了[zhdate](https://github.com/CutePandaSh/zhdate)模块。使用GPL3.0协议开放源代码。

***

如果遇到`ModuleNotFoundError`(Python 3.6+)或`ImportError`(Python 3.5-), 请先安装[zhdate](https://github.com/CutePandaSh/zhdate)模块。

欲安装[zhdate](https://github.com/CutePandaSh/zhdate)模块，请运行此命令：


```
pip install zhdate
```

亦或是在本项目目录下运行此命令:

```
pip install -r requirements.txt
```

然后再运行本程序。

***

如果以上方式无法解决你的问题，请向我们提交 issue.

==> holiday_predictor-1.0.0.tar.gz: holiday_predictor-1.0.0/README.md <==
# Holiday Predictor / 假期预测器

<div style="display: flex; align-items: center; justify-content: center; margin: 10px">
      <img
        align=center
        src="https://img.shields.io/github/stars/azaz-az/holiday-predictor?style=for-the-badge&logoColor=%231677ff&labelColor=rgb(89, 89, 89)&color=rgb(3, 126, 187)"
        style="margin: 0 5px"
      />
    <img
        align=center
        src="https://img.shields.io/github/watchers/azaz-az/holiday-predictor?style=for-the-badge&logoColor=%231677ff&labelColor=rgb(89, 89, 89)&color=rgb(3, 126, 187)"
        style="margin: 0 5px"
      />
    <img
        align=center
        src="https://img.shields.io/github/forks/azaz-az/holiday-predictor?style=for-the-badge&logoColor=%231677ff&labelColor=rgb(89, 89, 89)&color=rgb(3, 126, 187)"
        style="margin: 0 5px"
      />
</div>

***

简体中文 (中国大陆) / [English (US)](./README_en_us.md)

***

> [!WARNING]
> 此小工具仅用作假期安排的预测，不一定准确，仅供参考，并不完全代表假期安排。

这个小工具可以预测后续国庆、元旦、清明、端午和中秋的放假安排, 例如什么时候放假、什么时候调休。

本仓库在 GitHub 上开源，同时在 PyPI 上发布。

[![Click To GitHub Repo](https://img.shields.io/badge/click_to-github_repo-%2300fffd?style=for-the-badge)](https://github.com/azaz-az/holiday-predictor)
[![Click To PyPI](https://img.shields.io/badge/click_to-pypi-%23fdda50?style=for-the-badge)](https://pypi.org/project/holiday-predictor/)

贡献者名单：

[![Click To Contributors List](https://img.shields.io/badge/click_to-contributors_list-%2362ff7b?style=for-the-badge)](https://github.com/azaz-az/holiday-predictor/graphs/contributors)

> [!TIP]
> 这个小工具还可以作为模块导入.
> 
> 模块安装方式：
> 
> ```
> pip install holiday-predictor
> ```
> 在您的项目中使用：您可以在您的项目中使用
> ```
> import holiday_predictor
> ```
> 来导入本模块。

本项目使用了[zhdate](https://github.com/CutePandaSh/zhdate)模块。使用GPL3.0协议开放源代码。

***

如果遇到`ModuleNotFoundError`(Python 3.6+)或`ImportError`(Python 3.5-), 请先安装[zhdate](https://github.com/CutePandaSh/zhdate)模块。

欲安装[zhdate](https://github.com/CutePandaSh/zhdate)模块，请运行此命令：


```
pip install zhdate
```

亦或是在本项目目录下运行此命令:

```
pip install -r requirements.txt
```

然后再运行本程序。

***

如果以上方式无法解决你的问题，请向我们提交 issue.
